# Generated by roxygen2: do not edit by hand

export(GeomBrain)
export(annotate_brain)
export(aseg)
export(brain_join)
export(dk)
export(geom_brain)
export(ggseg)
export(position_brain)
export(reposition_brain)
export(scale_brain)
export(scale_brain2)
export(scale_brain_manual)
export(scale_color_brain)
export(scale_color_brain2)
export(scale_color_brain_manual)
export(scale_colour_brain)
export(scale_colour_brain2)
export(scale_colour_brain_manual)
export(scale_continous_brain)
export(scale_fill_brain)
export(scale_fill_brain2)
export(scale_fill_brain_manual)
export(scale_labs_brain)
export(scale_x_brain)
export(scale_y_brain)
export(theme_brain)
export(theme_brain2)
export(theme_custombrain)
export(theme_darkbrain)
export(tracula)
importFrom(dplyr,as_tibble)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,is.grouped_df)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,.pt)
importFrom(ggplot2,Geom)
importFrom(ggplot2,GeomPolygon)
importFrom(ggplot2,Position)
importFrom(ggplot2,aes)
importFrom(ggplot2,alpha)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,draw_key_polygon)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,ggproto_parent)
importFrom(ggplot2,labs)
importFrom(ggplot2,layer)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggseg.formats,aseg)
importFrom(ggseg.formats,atlas_palette)
importFrom(ggseg.formats,dk)
importFrom(ggseg.formats,tracula)
importFrom(sf,st_as_sf)
importFrom(sf,st_combine)
importFrom(sf,st_coordinates)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,capture.output)
importFrom(utils,getFromNamespace)
